@@ -10,6 +10,32 @@ our @ISA = qw(SelectPdf::ApiClient);
 
 SelectPdf::HtmlToPdfClient - Html To Pdf Conversion with SelectPdf Online API.
 
+=head1 SYNOPSIS
+ 
+    use SelectPdf;
+    print "This is SelectPdf-$SelectPdf::VERSION\n";
+
+    my $url = "https://selectpdf.com/";
+    my $local_file = "Test.pdf";
+    my $apiKey = "Your API key here";
+
+    eval {
+        my $client = new HtmlToPdfClient($apiKey);
+        
+        $client
+            ->setPageSize("A4")
+            ->setMargins(0)
+            ->setShowPageNumbers('False')
+            ->setPageBreaksEnhancedAlgorithm('True')
+        ;
+
+        $client->convertUrlToFile($url, $local_file);
+    };
+
+    if ($@) {
+        print "An error occurred: $@\n";  
+    }
+
 =head1 METHODS
 
 =head2 new( $apiKey )
